@@ -63,4 +63,27 @@ class CompressedJsonSerializer(object):
         '''
         return json.loads(zlib.decompress(v))
 
+# -----------------------------------------------------------------
+# CompressedJStrSerializer class
+# -----------------------------------------------------------------
+
+class CompressedStrSerializer(object):
+    ''' CompressedStrSerializer 
+    '''
+
+    @staticmethod
+    def dumps(v):
+        ''' dumps value 
+        '''
+        if v is None:
+            return None
+        return zlib.compress(v)
+
+    @staticmethod
+    def loads(v):
+        ''' loads value  
+        '''
+        if v is None:
+            return None
+        return zlib.decompress(v)
 
